from .Die import Die

class DiceSet:
    """ Simple set of dice with custom number of sides.
    Any dice set can have any number of dice and each dice having the same number of sides.

    Attributes:
        dice (int) representing the number of dice in the box
        sides (int) representing the number of sides each die has
    """
    
    def __init__(self, dice=1, sides=6):
        
        self.dice = self.create_dice_box(dice, sides)
        self.sides = sides
       
    
    def create_dice_box(self, dice, sides):
        """ Function to create a list of Die objects.
        To be used to store the list of dice in the DiceSet object.

        Args: 
            dice (int): number of dice in the dice set
            sides (int): number of sides each die has
        
        Returns: 
            list(Die): list of Die objects in the dice set

        """
            
        dice_list = []
        
        for i in range(dice):
            die = Die(sides)
            dice_list.append(die)
        
        return dice_list
    
    
    def roll(self, verbose=False):
        """ Function to roll the dice set.

        Args: 
            verbose (optional): if True, verbose will also print the list of outcomes
        
        Returns: 
            list(int): list of outcomes for each die roll

        """
            
        rolls = [die.roll() for die in self.dice]
        
        if verbose:
            print(rolls)
            
        return rolls
    
    
    def __repr__(self):

        """ Function to output the characteristics of the dice set

        Args:
            None
        
        Returns:
            string: characteristics of the dice set

        """

        return "dice set of {} dice with {} sides".format(len(self.dice), self.sides)


from setuptools import setup

setup(name='diceset',
      version='0.1',
      description='A simple dice set creator and roller.',
      packages=['diceset'],
      author = 'Alexandru Gradinaru',
      author_email = 'gradinaru.alex@gmail.com',
      zip_safe=False)



import random

class Die:
    """ Die object with a specified number of sides.
    
    Attributes:
        sides (int) representing the number of sides the die has
    """

    def __init__(self, sides=2):
        
        self.sides = sides

    def roll(self):
        """Function to roll the die.

        Args: 
            None

        Returns: 
            int: the outcome of the die roll

        """
            
        random.seed()
        return random.randrange(1, self.sides + 1)
    
    
    def __repr__(self):
        """Function to output the characteristics of the die.

        Args:
            None
        
        Returns:
            string: characteristics of the die

        """

        return "{} sided die".format(self.sides)